# dinkum

Directed Interaction NetworKs are fair dinkum!

## What is dinkum?

`dinkum` is a piece of software for simple modeling of gene regulatory
networks, based on the GeNeTool software described in
[Faure, Peter, and Davidson, 2013](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3667423/). It
supports simple definition of genes, tissues, ligands/receptors, and
regulatory influences, and is intended to run in Jupyter
Notebooks. It's primarily intended for teaching purposes, and was
developed for the 2024
[Gene Regulatory Networks for Development](https://www.mbl.edu/education/advanced-research-training-courses/course-offerings/gene-regulatory-networks-development)
course at the Marine Biological Laboratory.

To get started with dinkum, see [notebooks/getting-started.ipynb](notebooks/getting-started.ipynb).

## Why 'dinkum'?

Dinkum is a backronym constructed from "directed interaction
networks". It's also named in honor of one of the course directors,
who is Australian; it turns out that dinkum is one of the few
Australian-specific slang words that is not rude.

## Developing dinkum

Dinkum is developed on github under
[dinkum-bio/dinkum](https://github.com/dinkum-bio/dinkum/). It is
released under the GNU Affero General Public License v3 open source
license.

You can run the tests with `make test`.

CTB 10/2024
